==> Inirama-0.2.1.tar.gz: Inirama-0.2.1/tests/__init__.py <==
from unittest import TestCase

from inirama import Namespace


class MainTest(TestCase):

    def test_parse(self):
        parser = Namespace()
        parser.read('test.ini')
        parser.read('tests/test.ini', 'tests/invalid.ini', 'tests/append.ini')

        self.assertTrue(parser['main'])
        self.assertTrue(parser['main']['key'])
        self.assertTrue(parser['main']['additional'])
        self.assertEqual(parser['default']['defkey'], 'defvalue')
        self.assertEqual(parser['other']['foo'], 'bar/zeta')
        self.assertEqual(parser['other']['long'], 'long value')

        parser['main']['test'] = 123
        self.assertEqual(parser['main']['test'], '123')

    def test_interpolation(self):
        parser = Namespace()
        parser.read('tests/vars.ini')
        self.assertEqual(parser['main']['var_test'], 'Hello world!')

        parser['main']['foo'] = 'bar {var_test}'
        self.assertEqual(parser['main']['foo'], 'bar Hello world!')

        self.assertEqual(parser['main'].context, {'foo': 'bar Hello world!', 'test': 'world', 'var_test': 'Hello world!'})

        parser['main']['test'] = '{foo}'
        with self.assertRaises(ValueError):
            self.assertEqual(parser['main']['foo'], 'bar Hello world!')

        parser['main']['test'] = 'parse {unknown}done'
        self.assertEqual(parser['main']['test'], 'parse done')

    def test_write(self):
        from tempfile import mkstemp

        _, target = mkstemp()

        parser = Namespace()
        parser.read('tests/vars.ini')
        parser.write(target)

        with open(target) as f:
            source = f.read()
            self.assertTrue('[main]' in source)

==> Inirama-0.2.2.tar.gz: Inirama-0.2.2/tests/__init__.py <==
from unittest import TestCase

from inirama import Namespace, InterpolationNamespace


class MainTest(TestCase):

    def test_parse(self):
        parser = Namespace()
        parser.read('test.ini')
        parser.read('tests/test.ini', 'tests/invalid.ini', 'tests/append.ini')

        self.assertTrue(parser['main'])
        self.assertTrue(parser['main']['key'])
        self.assertTrue(parser['main']['additional'])
        self.assertEqual(parser['DEFAULT']['defkey'], 'defvalue')
        self.assertEqual(parser['other']['foo'], 'bar/zeta')
        self.assertEqual(parser['other']['long'], 'long value')
        self.assertEqual(parser['other']['safe_value'], 'c:\\\\test\\')
        self.assertEqual(parser['other']['b'], '[test]')

        parser['main']['test'] = 123
        self.assertEqual(parser['main']['test'], '123')

    def test_interpolation(self):
        parser = InterpolationNamespace()
        parser.default_section = 'main'
        parser.read('tests/vars.ini')
        self.assertEqual(parser['main']['var_test'], 'Hello world!')

        parser['main']['foo'] = 'bar {var_test}'
        self.assertEqual(parser['main']['foo'], 'bar Hello world!')

        parser['main']['test'] = '{foo}'
        with self.assertRaises(ValueError):
            self.assertEqual(parser['main']['foo'], 'bar Hello world!')

        parser['main']['test'] = 'parse {unknown}done'
        self.assertEqual(parser['main']['test'], 'parse done')
        self.assertEqual(parser['other']['b'], 'Hello parse done! start')

    def test_write(self):
        from tempfile import mkstemp

        _, target = mkstemp()

        parser = Namespace()
        parser.read('tests/vars.ini')
        parser.write(target)

        with open(target) as f:
            source = f.read()
            self.assertTrue('[main]' in source)
